@@ -18,6 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h" // For GLOM_ENABLE_MAEMO
+
 #include <glom/libglom/utils.h>
 #include <glom/libglom/connectionpool.h>
 #include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
@@ -25,8 +27,16 @@
 
 #include <glibmm/i18n.h>
 #include <gtkmm/messagedialog.h>
+
+#ifndef GLOM_ENABLE_MAEMO
 #include <libgnome/gnome-url.h>
 #include <libgnome/gnome-help.h>
+#endif
+
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/note.h>
+#endif
+
 #include <sstream> //For stringstream
 
 #include <iostream>
@@ -39,6 +49,14 @@
 
 #include <stack>
 
+#ifdef GLOM_ENABLE_MAEMO
+const unsigned int Glom::Utils::DEFAULT_SPACING_LARGE =  1;
+const unsigned int Glom::Utils::DEFAULT_SPACING_SMALL =  1;
+#else
+const unsigned int Glom::Utils::DEFAULT_SPACING_LARGE = 12;
+const unsigned int Glom::Utils::DEFAULT_SPACING_SMALL =  6;
+#endif
+
 namespace Glom
 {
 
@@ -416,11 +434,21 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
 
   //std::cout << "debug: get_choice_values(): query: " << sql_query << std::endl;
   //Connect to database:
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect();
-
+#else
+  std::auto_ptr<ExceptionConnection> conn_error;
+  sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect(conn_error);
+  if(conn_error.get() != NULL) return list_values;
+#endif
 
   //std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_single_command(sql_query);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_select_command(sql_query);
+#else
+  std::auto_ptr<Glib::Error> error;
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_select_command(sql_query, error);
+#endif
 
   if(datamodel)
   {
@@ -432,7 +460,7 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
       itempair.first = datamodel->get_value_at(0, row);
 
       if(with_second)
-			itempair.second = datamodel->get_value_at(1, row);
+                        itempair.second = datamodel->get_value_at(1, row);
 
       list_values.push_back(itempair);
     }
@@ -510,33 +538,24 @@ Glib::ustring Utils::create_local_image_uri(const Gnome::Gda::Value& value)
 
   Glib::ustring result;
 
-  if(value.get_value_type() == Gnome::Gda::VALUE_TYPE_BINARY)
+  if(value.get_value_type() == GDA_TYPE_BINARY)
   {
     glong size = 0;
-    const gpointer pData = value.get_binary(size);
+    gconstpointer pData = value.get_binary(size);
     if(size && pData)
     {
-      //libgda does not currently properly unescape binary data,
-      //so pData is actually a null terminated string, of escaped binary data.
-      //This workaround should be removed when libgda is fixed:
-      //(It is fixed in libgd-2.0 but is unlikely to be fixed in libgda-1.2)
-      size_t buffer_binary_length = 0;
-      guchar* buffer_binary =  Glom_PQunescapeBytea((const guchar*)pData /* must be null-terminated */, &buffer_binary_length); //freed by us later.
-      if(buffer_binary)
+      // Note that this is regular binary data, not escaped text representing the data:
+
+      //Save the image to a temporary file and provide the file URI.
+      char pchExtraNum[10];
+      sprintf(pchExtraNum, "%d", m_temp_image_uri_number);
+      result = ("/tmp/glom_report_image_" + Glib::ustring(pchExtraNum) + ".png");
+      ++m_temp_image_uri_number;
+
+      std::fstream the_stream(result.c_str(), std::ios_base::out | std::ios_base::trunc | std::ios_base::binary);
+      if(the_stream)
       {
-        //Saves the image to a temporary file and provides the file URI.
-        char pchExtraNum[10];
-        sprintf(pchExtraNum, "%d", m_temp_image_uri_number);
-        result = ("/tmp/glom_report_image_" + Glib::ustring(pchExtraNum) + ".png");
-        ++m_temp_image_uri_number;
-
-        std::fstream the_stream(result.c_str(), std::ios_base::out | std::ios_base::trunc | std::ios_base::binary);
-        if(the_stream)
-        {
-          the_stream.write((char*)buffer_binary, buffer_binary_length);
-        }
-
-        free(buffer_binary);
+        the_stream.write((char*)pData, size);
       }
     }
     else
@@ -657,7 +676,7 @@ Utils::type_vecStrings Utils::string_separate(const Glib::ustring& str, const Gl
           //Which quote, if any, is first:
           Glib::ustring::size_type posFirstQuote = posSingleQuote;
           if( (posDoubleQuote != Glib::ustring::npos) && (posDoubleQuote < posFirstQuote) )
-	    posFirstQuote = posDoubleQuote;
+            posFirstQuote = posDoubleQuote;
 
           //Ignore quotes that are _after_ the separator:
           if( posFirstQuote >= posComma)
@@ -709,10 +728,16 @@ Utils::type_vecStrings Utils::string_separate(const Glib::ustring& str, const Gl
         //Store this item, and start the next item after it:
         item = str.substr(item_start, posComma - item_start);
         //std::cout << "  ITEM. pos_comma=" << posComma << ", ITEM= " << item << std::endl;
-	item_start = posComma + size_separator;
+        item_start = posComma + size_separator;
+      }
+      else
+      {
+        //std::cout << "in quotes." << std::endl;
+        // Continue behind separator
+        unprocessed_start = posComma + size_separator;
+        // Do not add this item to the result, because it was quoted.
+        continue;
       }
-      //else
-      //  std::cout << "in quotes." << std::endl;
      
       unprocessed_start = posComma + size_separator; //The while loops stops when this is empty.
     }
@@ -807,7 +832,10 @@ void Utils::show_help(const Glib::ustring& id)
   else
   {
     pId = 0;
-   }   
+   }
+
+  // TODO_maemo: Show help on maemo by some other means
+#ifndef GLOM_ENABLE_MAEMO
   if (!gnome_help_display("glom.xml", pId, &err))
   {
      std::string message = std::string(_("Could not display help: ")) + err->message;
@@ -816,14 +844,20 @@ void Utils::show_help(const Glib::ustring& id)
      delete dialog;
      g_error_free(err);
    }
+#endif
 }
 
 
 void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
 {
+#ifdef GLOM_ENABLE_MAEMO
+  // TODO_maemo: Map message_type to a senseful stock_id?
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, parent, message);
+#else
   Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
   dialog.set_transient_for(parent);
+#endif
   dialog.run();
 }
 
