@@ -36,7 +36,7 @@ namespace Glom
 {
 
 Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
-: m_HBox(false, 6),
+: m_HBox(false, Utils::DEFAULT_SPACING_SMALL),
   m_Button_New(Gtk::Stock::ADD),
   m_Button_Del(Gtk::Stock::DELETE),
   m_Button_Nav_First(Gtk::Stock::GOTO_FIRST),
@@ -50,6 +50,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 
   add_view(&m_FlowTable); //Allow this to access the document too.
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_data_layout"); //TODO: Use a generic layout dialog?
   if(refXml)
   {
@@ -62,15 +63,20 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
       m_pDialogLayout->signal_hide().connect( sigc::mem_fun(static_cast<Box_Data&>(*this), &Box_Data::on_dialog_layout_hide) );
     }
   }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   m_FlowTable.set_columns_count(1); //Sub-groups will have multiple columns (by default, there is one sub-group, with 2 columns).
-  m_FlowTable.set_padding(6);
+  m_FlowTable.set_padding(Utils::DEFAULT_SPACING_SMALL);
 
   //m_strHint = _("When you change the data in a field the database is updated immediately.\n Click [New] to add a new record.\n Leave automatic ID fields empty - they will be filled for you.");
 
 
-  //m_ScrolledWindow.set_border_width(6);
+  //m_ScrolledWindow.set_border_width(Utils::DEFAULT_SPACING_SMALL);
+#ifdef GLOM_ENABLE_MAEMO
+  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC); /* Allow horizontal scrolling in maemo because the screen is rather small and there might be some database UIs that don't fit horizontally. Such a UI may be concidered non-maemo-friendly, but it can still be fully viewed this way. */
+#else
   m_ScrolledWindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC); /* Allow vertical scrolling, but never scroll horizontally. */
+#endif
   m_ScrolledWindow.set_shadow_type(Gtk::SHADOW_NONE); //SHADOW_IN is Recommended by the GNOME HIG, but looks odd.
   pack_start(m_ScrolledWindow);
   m_ScrolledWindow.add(m_FlowTable);
@@ -111,7 +117,9 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   m_FlowTable.signal_related_record_changed().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_related_record_changed) );
 
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   m_FlowTable.signal_layout_changed().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_layout_changed) );
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   m_FlowTable.signal_requested_related_details().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_requested_related_details) );
 
@@ -206,14 +214,38 @@ bool Box_Data_Details::fill_from_database()
     return false;
   }
 
+  //TODO: This should keep the connection open, so we don't need to 
+  //reconnect many times..
+  sharedptr<SharedConnection> sharedconnection;
+
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+    sharedconnection = connect_to_server(get_app_window());
+  }
+  catch(const Glib::Exception& ex)
+  {
+    handle_error(ex);
+    bResult = false;
+  }
+  catch(const std::exception& ex)
+  {
+    handle_error(ex);
+    bResult = false;
+  }
+#else
+  std::auto_ptr<ExceptionConnection> error;
+  sharedconnection = connect_to_server(get_app_window(), error);
+  if(error.get())
+  {
+    handle_error(*error);
+    bResult = false;
+  }
+#endif
 
-    //TODO: This should keep the connection open, so we don't need to 
-    //reconnect many times..
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
-
-
+  if(sharedconnection)
+  {
+    // TODO: Can this throw?
     bResult = Box_Data::fill_from_database();
 
     m_FieldsShown = get_fields_to_show();
@@ -299,16 +331,6 @@ bool Box_Data_Details::fill_from_database()
     fill_end();
 
   }
-  catch(const Glib::Exception& ex)
-  {
-    handle_error(ex);
-    bResult = false;
-  }
-  catch(const std::exception& ex)
-  {
-    handle_error(ex);
-    bResult = false;
-  }
 
   return bResult;
 }
@@ -500,6 +522,7 @@ Box_Data_Details::type_signal_requested_related_details Box_Data_Details::signal
   return m_signal_requested_related_details;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Data_Details::on_flowtable_layout_changed()
 {
   //Get new layout:
@@ -518,6 +541,7 @@ void Box_Data_Details::on_flowtable_layout_changed()
   //And fill it with data:
   fill_from_database();
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 void Box_Data_Details::on_flowtable_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
 {
@@ -643,10 +667,25 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     m_FlowTable.set_field_value(layout_field, field_value);
 
     //Update the field in the record (the record with this primary key):
-    try
-    {
-      const bool bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
 
+    bool bTest = false;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+#endif // GLIBMM_EXCEPTIONS_ENABLED
+    {
+      bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
+    }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    catch(const std::exception& ex)
+    {
+      handle_error(ex);
+    }
+#endif // GLIBMM_EXCEPTIONS_ENABLED
+
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+#endif // GLIBMM_EXCEPTIONS_ENABLED
+    {
       if(!bTest)
       {
         //Update failed.
@@ -677,6 +716,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       }
 
     }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::Exception& ex)
     {
       handle_error(ex);
@@ -685,6 +725,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     {
       handle_error(ex);
     }
+#endif // GLIBMM_EXCEPTIONS_ENABLED
   }
   else
   {
@@ -743,7 +784,9 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
 
 void Box_Data_Details::on_userlevel_changed(AppState::userlevels user_level)
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   m_FlowTable.set_design_mode( user_level == AppState::USERLEVEL_DEVELOPER );
+#endif
 }
 
 sharedptr<Field> Box_Data_Details::get_field_primary_key() const
