@@ -21,6 +21,9 @@
 #include "notebook_glom.h"
 #include "application.h"
 
+namespace Glom
+{
+
 Notebook_Glom::Notebook_Glom()
 {
   m_uiPreviousPage = 0;
@@ -46,7 +49,8 @@ Notebook_Glom::type_signal_leave_page Notebook_Glom::signal_leave_page()
 void Notebook_Glom::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageNumber)
 {
   //Call base class:
-  Gtk::Notebook::on_switch_page(pPage, uiPageNumber);
+  //Don't call base class because this is no default signal handler (anymore?)
+  //Gtk::Notebook::on_switch_page(pPage, uiPageNumber);
 
   //Remove the help hint for the previous page:
   Gtk::Window* pApp = get_app_window();
@@ -134,3 +138,5 @@ void Notebook_Glom::do_menu_file_print()
 {
   //Override this.
 }
+
+} //namespace Glom
